import { PatchedRequest } from './internal-types';
export declare const addNewStackLayer: (request: PatchedRequest) => () => void;
export declare const replaceCurrentStackRoute: (request: PatchedRequest, newRoute?: string | undefined) => void;
export declare const generateRoute: (request: PatchedRequest) => string;
//# sourceMappingURL=utils.d.ts.map