export declare enum AttributeNames {
    CONNECT_TYPE = "connect.type",
    CONNECT_NAME = "connect.name"
}
export declare enum ConnectTypes {
    MIDDLEWARE = "middleware",
    REQUEST_HANDLER = "request_handler"
}
export declare enum ConnectNames {
    MIDDLEWARE = "middleware",
    REQUEST_HANDLER = "request handler"
}
//# sourceMappingURL=AttributeNames.d.ts.map